@@ -19,28 +19,14 @@ import subprocess
 import sys
 import time
 import platform
-PY2 = False
-try:
-    # python 3
-    from urllib.parse import urlparse
-    from urllib.parse import quote as urlquote
-    from urllib.parse import urlencode
-    from urllib.error import HTTPError, URLError
-    from urllib.request import urlopen
-    from urllib.request import Request
-    from urllib.request import HTTPRedirectHandler
-    from urllib.request import build_opener
-except ImportError:
-    # python 2
-    PY2 = True
-    from urlparse import urlparse
-    from urllib import quote as urlquote
-    from urllib import urlencode
-    from urllib2 import HTTPError, URLError
-    from urllib2 import urlopen
-    from urllib2 import Request
-    from urllib2 import HTTPRedirectHandler
-    from urllib2 import build_opener
+from urllib.parse import urlparse
+from urllib.parse import quote as urlquote
+from urllib.parse import urlencode
+from urllib.error import HTTPError, URLError
+from urllib.request import urlopen
+from urllib.request import Request
+from urllib.request import HTTPRedirectHandler
+from urllib.request import build_opener
 
 try:
     from . import __version__
@@ -276,6 +262,10 @@ def parse_args():
                         action='store_true',
                         dest='include_starred_gists',
                         help='include starred gists in backup [*]')
+    parser.add_argument('--skip-archived',
+                        action='store_true',
+                        dest='skip_archived',
+                        help='skip project if it is archived')
     parser.add_argument('--skip-existing',
                         action='store_true',
                         dest='skip_existing',
@@ -360,10 +350,9 @@ def get_auth(args, encode=True, for_git_cli=False):
                         '-s', args.osx_keychain_item_name,
                         '-a', args.osx_keychain_item_account,
                         '-w'], stderr=devnull).strip())
-                if not PY2:
-                    token = token.decode('utf-8')
+                token = token.decode('utf-8')
                 auth = token + ':' + 'x-oauth-basic'
-            except:
+            except subprocess.SubprocessError:
                 log_error('No password item matching the provided name and account could be found in the osx keychain.')
     elif args.osx_keychain_item_account:
         log_error('You must specify both name and account fields for osx keychain password items')
@@ -421,8 +410,8 @@ def get_github_repo_url(args, repository):
     if repository.get('is_gist'):
         if args.prefer_ssh:
             # The git_pull_url value is always https for gists, so we need to transform it to ssh form
-            repo_url = re.sub('^https?:\/\/(.+)\/(.+)\.git$', r'git@\1:\2.git', repository['git_pull_url'])
-            repo_url = re.sub('^git@gist\.', 'git@', repo_url) # strip gist subdomain for better hostkey compatibility
+            repo_url = re.sub(r'^https?:\/\/(.+)\/(.+)\.git$', r'git@\1:\2.git', repository['git_pull_url'])
+            repo_url = re.sub(r'^git@gist\.', 'git@', repo_url)  # strip gist subdomain for better hostkey compatibility
         else:
             repo_url = repository['git_pull_url']
         return repo_url
@@ -431,7 +420,7 @@ def get_github_repo_url(args, repository):
         return repository['ssh_url']
 
     auth = get_auth(args, encode=False, for_git_cli=True)
-    if auth and repository['private'] == True:
+    if auth and repository['private'] is True:
         repo_url = 'https://{0}@{1}/{2}/{3}.git'.format(
             auth,
             get_github_host(args),
@@ -495,9 +484,11 @@ def retrieve_data_gen(args, template, query_args=None, single_request=False):
         if single_request:
             break
 
+
 def retrieve_data(args, template, query_args=None, single_request=False):
     return list(retrieve_data_gen(args, template, query_args, single_request))
 
+
 def get_query_args(query_args=None):
     if not query_args:
         query_args = {}
@@ -545,8 +536,7 @@ def _construct_request(per_page, page, query_args, template, auth, as_app=None):
         if not as_app:
             request.add_header('Authorization', 'Basic '.encode('ascii') + auth)
         else:
-            if not PY2:
-                auth = auth.encode('ascii')
+            auth = auth.encode('ascii')
             request.add_header('Authorization', 'token '.encode('ascii') + auth)
             request.add_header('Accept', 'application/vnd.github.machine-man-preview+json')
     log_info('Requesting {}?{}'.format(template, querystring))
@@ -604,11 +594,7 @@ class S3HTTPRedirectHandler(HTTPRedirectHandler):
     so we should remove said header on redirect.
     """
     def redirect_request(self, req, fp, code, msg, headers, newurl):
-        if PY2:
-            # HTTPRedirectHandler is an old style class
-            request = HTTPRedirectHandler.redirect_request(self, req, fp, code, msg, headers, newurl)
-        else:
-            request = super(S3HTTPRedirectHandler, self).redirect_request(req, fp, code, msg, headers, newurl)
+        request = super(S3HTTPRedirectHandler, self).redirect_request(req, fp, code, msg, headers, newurl)
         del request.headers['Authorization']
         return request
 
@@ -738,6 +724,8 @@ def filter_repositories(args, unfiltered_repositories):
         repositories = [r for r in repositories if r.get('language') and r.get('language').lower() in languages]  # noqa
     if name_regex:
         repositories = [r for r in repositories if name_regex.match(r['name'])]
+    if args.skip_archived:
+        repositories = [r for r in repositories if not r.get('archived')]
 
     return repositories
 
@@ -901,18 +889,22 @@ def backup_pulls(args, repo_cwd, repository, repos_template):
         pull_states = ['open', 'closed']
         for pull_state in pull_states:
             query_args['state'] = pull_state
-            _pulls = retrieve_data_gen(args,
-                                   _pulls_template,
-                                   query_args=query_args)
+            _pulls = retrieve_data_gen(
+                args,
+                _pulls_template,
+                query_args=query_args
+            )
             for pull in _pulls:
                 if args.since and pull['updated_at'] < args.since:
                     break
                 if not args.since or pull['updated_at'] >= args.since:
                     pulls[pull['number']] = pull
     else:
-        _pulls = retrieve_data_gen(args,
-                               _pulls_template,
-                               query_args=query_args)
+        _pulls = retrieve_data_gen(
+            args,
+            _pulls_template,
+            query_args=query_args
+        )
         for pull in _pulls:
             if args.since and pull['updated_at'] < args.since:
                 break
